Groups
======

.. toctree::
   :maxdepth: 1

   sage/groups/groups_catalog
   sage/groups/group
   sage/groups/libgap_morphism
   sage/groups/libgap_wrapper
   sage/groups/libgap_group
   sage/groups/libgap_mixin
   sage/groups/pari_group
   sage/groups/generic
   sage/groups/free_group
   sage/groups/finitely_presented
   sage/groups/finitely_presented_named
   sage/groups/braid
   sage/groups/cubic_braid
   sage/groups/indexed_free_group
   sage/groups/artin
   sage/groups/raag
   sage/groups/cactus_group
   sage/groups/group_exp
   sage/groups/group_semidirect_product
   sage/groups/misc_gps/misc_groups
   sage/groups/semimonomial_transformations/semimonomial_transformation_group
   sage/groups/semimonomial_transformations/semimonomial_transformation
   sage/groups/kernel_subgroup
   sage/groups/class_function
   sage/groups/conjugacy_classes

Abelian Groups
--------------

.. toctree::
   :maxdepth: 1

   sage/groups/abelian_gps/abelian_group
   sage/groups/abelian_gps/abelian_group_gap
   sage/groups/abelian_gps/abelian_aut
   sage/groups/abelian_gps/values
   sage/groups/abelian_gps/dual_abelian_group
   sage/groups/abelian_gps/element_base
   sage/groups/abelian_gps/abelian_group_element
   sage/groups/abelian_gps/dual_abelian_group_element
   sage/groups/abelian_gps/abelian_group_morphism
   sage/groups/additive_abelian/additive_abelian_group
   sage/groups/additive_abelian/additive_abelian_wrapper
   sage/groups/misc_gps/argument_groups
   sage/groups/misc_gps/imaginary_groups

Permutation Groups
------------------

.. toctree::
   :maxdepth: 1

   sage/groups/perm_gps/permutation_groups_catalog
   sage/groups/perm_gps/constructor
   sage/groups/perm_gps/permgroup
   sage/groups/perm_gps/permgroup_named
   sage/groups/perm_gps/permgroup_element
   sage/groups/perm_gps/permgroup_morphism
   sage/groups/perm_gps/cubegroup
   sage/groups/perm_gps/symgp_conjugacy_class

Matrix and Affine Groups
------------------------

.. toctree::
   :maxdepth: 1

   sage/groups/matrix_gps/catalog
   sage/groups/matrix_gps/matrix_group
   sage/groups/matrix_gps/matrix_group_gap
   sage/groups/matrix_gps/group_element
   sage/groups/matrix_gps/group_element_gap
   sage/groups/matrix_gps/finitely_generated
   sage/groups/matrix_gps/finitely_generated_gap
   sage/groups/matrix_gps/binary_dihedral
   sage/groups/matrix_gps/coxeter_group
   sage/groups/matrix_gps/linear
   sage/groups/matrix_gps/linear_gap
   sage/groups/matrix_gps/orthogonal
   sage/groups/matrix_gps/orthogonal_gap
   sage/groups/matrix_gps/isometries
   sage/groups/matrix_gps/symplectic
   sage/groups/matrix_gps/symplectic_gap
   sage/groups/matrix_gps/unitary
   sage/groups/matrix_gps/unitary_gap
   sage/groups/matrix_gps/heisenberg
   sage/groups/affine_gps/affine_group
   sage/groups/affine_gps/euclidean_group
   sage/groups/affine_gps/group_element

Lie Groups
------------------------

.. toctree::
   :maxdepth: 1

   sage/groups/lie_gps/nilpotent_lie_group

Partition Refinement
--------------------

.. toctree::
   :maxdepth: 1

   sage/groups/perm_gps/partn_ref/canonical_augmentation
   sage/groups/perm_gps/partn_ref/data_structures
   sage/groups/perm_gps/partn_ref/refinement_graphs
   sage/groups/perm_gps/partn_ref/refinement_lists
   sage/groups/perm_gps/partn_ref/refinement_matrices

Internals
---------

.. toctree::
   :maxdepth: 1

   sage/groups/matrix_gps/named_group
   sage/groups/matrix_gps/named_group_gap

.. include:: ../footer.txt
